@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkContextView extends vtkRenderViewBase
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkContextView extends vtkRenderViewBase
 
     if (temp == 0) return null;
     return (vtkContext2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetScene_4(vtkContextScene id0);
   public void SetScene(vtkContextScene id0)
@@ -37,7 +37,7 @@ public class vtkContextView extends vtkRenderViewBase
 
     if (temp == 0) return null;
     return (vtkContextScene)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   public vtkContextView() { super(); }
 
