@@ -299,9 +299,13 @@ public class vtkPolyData extends vtkPointSet
   public int GetScalarFieldCriticalIndex(int id0,String id1)
     { return GetScalarFieldCriticalIndex_65(id0,id1); }
 
-  private native long GetCell_66(int id0,int id1,int id2);
+  private native int GetMeshMTime_66();
+  public int GetMeshMTime()
+    { return GetMeshMTime_66(); }
+
+  private native long GetCell_67(int id0,int id1,int id2);
   public vtkCell GetCell(int id0,int id1,int id2) {
-    long temp = GetCell_66(id0,id1,id2);
+    long temp = GetCell_67(id0,id1,id2);
 
     if (temp == 0) return null;
     return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
